@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Git::Helpers;
-our $VERSION = '0.000017';
+our $VERSION = '0.000018';
 use Carp qw( croak );
 use Capture::Tiny 'capture_stderr';
 use File::pushd qw( pushd );
@@ -12,6 +12,7 @@ use Sub::Exporter -setup => {
         'checkout_root',
         'current_branch_name',
         'https_remote_url',
+        'ignored_files',
         'is_inside_work_tree',
         'remote_url',
         'travis_url',
@@ -84,6 +85,23 @@ sub is_inside_work_tree {
     return $success;
 }
 
+sub ignored_files {
+    my $dir = shift || '.';
+    my @success;
+    my $stderr = capture_stderr {
+        try {
+            @success = git::ls_files(
+                $dir, '--ignored', '--exclude-standard',
+                '--others'
+            );
+        };
+    };
+
+    croak "Cannot find ignored files in dir: $stderr" if $stderr;
+
+    return \@success || [];
+}
+
 sub remote_url {
     my $remote = shift || 'origin';
     my $url;
@@ -128,7 +146,7 @@ Git::Helpers - Shortcuts for common Git commands
 
 =head1 VERSION
 
-version 0.000017
+version 0.000018
 
 =head1 SYNOPSIS
 
@@ -178,6 +196,13 @@ Defaults to master branch, but can also display current branch.
 
     my $current_branch_url = https_remote_url( 'origin', 1 );
 
+=head2 ignored_files( $dir )
+
+Returns an arrayref of files which exist in your checkout, but are ignored by
+Git.  Optionally accepts a directory as an argument.  Defaults to ".".
+
+Throws an exception if there has been an error running the command.
+
 =head2 is_inside_work_tree
 
 Returns C<true> if C<git rev-parse --is-inside-work-tree> returns C<true>.
